@@ -63,7 +63,10 @@ public:
     void emitNotification(const QString &evid, const QString &message = QString(),
                           const QString &iconname = QString());
     void emitRichNotification(const QString &evid, const QString &title, const QString &message = QString());
-    bool emitBatteryChargePercentNotification(int currentPercent, int previousPercent);
+
+    void emitNotification(const QString &eventId, const QString &title, const QString &message, const QString &iconName);
+
+    bool emitBatteryChargePercentNotification(int currentPercent, int previousPercent, const QString &udi = QString());
 
     BackendInterface *backend();
 
@@ -106,16 +109,17 @@ private:
     friend class Action;
 
     BackendInterface *m_backend;
-    QStringList m_loadedBatteriesUdi;
 
     QDBusServiceWatcher *m_notificationsWatcher;
+    bool m_notificationsReady = false;
 
     KSharedConfigPtr m_profilesConfig;
 
     QString m_currentProfile;
 
-    QHash< QString, int > m_batteriesPercent;
-    QHash< QString, bool > m_batteriesCharged;
+    QHash<QString, int> m_batteriesPercent;
+    QHash<QString, int> m_peripheralBatteriesPercent;
+    QHash<QString, bool> m_batteriesCharged;
 
     QTimer *m_criticalBatteryTimer;
     QPointer<KNotification> m_criticalBatteryNotification;
